#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Jan 26 15:30:16 2023

"""

import os
from surprisal import AutoHuggingFaceModel
from sys import platform
import torch

# set env variable to avoid the following warning:
# huggingface/tokenizers: The current process just got forked, after parallelism has already been used....
os.environ["TOKENIZERS_PARALLELISM"] = "false"
use_cuda = torch.cuda.is_available()

bloom_distrib = 'bigscience/bloom-petals'
class_distrib = 'petals'

bloom_local = 'bigscience/bloom-1b7'
class_local = 'gpt'


sentences = [
    "The cat is on the mat",
    "The cat is on the hat",
    "The cat is on the pizza",
    "The pizza is on the mat",
    "I told you that the cat is on the mat",
    "I told you the cat is on the mat",
]

print(f'Loading {bloom_local} model and testing...',flush=True)
localLM = AutoHuggingFaceModel.from_pretrained(bloom_local, model_class = class_local)
if use_cuda:
    localLM.to('cuda')

for result in localLM.surprise(sentences):
    print(result)
    
if platform == 'linux':
    print(f'Loading {bloom_distrib} model and testing...',flush=True)
    distributedLM = AutoHuggingFaceModel.from_pretrained(bloom_distrib, model_class = class_distrib)
    if use_cuda:
        distributedLM.to('cuda')
    for result in distributedLM.surprise(sentences):
        print(result)
else:
    print(f'Sorry, {bloom_distrib} requires a linux system (process aborted)')